# Python: Rivian API Client

Currently a Work In Progress

## Dependencies

[Poetry](https://python-poetry.org/docs/)

```
curl -sSL https://install.python-poetry.org | python3 -
```

## Setup

Install project dependencies into the poetry virtual environment.

```
poetry install
```

## Run Tests

```
poetry run pytest
```
